@@ -12,7 +12,8 @@ from django.conf import settings
 from django.shortcuts import redirect
 from rest_framework import response
 
-from revpayment.exceptions import HttpActionError, InvalidCallback, PaymentException
+from revpayment.exceptions import (HttpActionError, InvalidCallback,
+                                   PaymentException)
 from revpayment.settings import api_settings
 
 SNS_MESSAGE_TYPE_SUB_NOTIFICATION = "SubscriptionConfirmation"
