@@ -1,16 +1,17 @@
-default_app_config = 'revpayment.invoice.apps.RevpaymentInvoiceConfig'
+default_app_config = "revpayment.invoice.apps.RevpaymentInvoiceConfig"
 
 
 class InvoiceSDK:
-    def __init__(self, order=None, invoice_type='neweb'):
+    def __init__(self, order=None, invoice_type="neweb"):
         self.order = order
         self.invoice_type = invoice_type
 
     def get_provider_class(self):
         from .providers import EcpayProvider, NewebProvider
-        if self.invoice_type == 'ecpay':
+
+        if self.invoice_type == "ecpay":
             return EcpayProvider
-        elif self.invoice_type == 'neweb':
+        elif self.invoice_type == "neweb":
             return NewebProvider
 
     def get_provider(self, **kwargs):
